@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2018, Ilya Kotov <forkotov02@ya.ru>
+ * Copyright (c) 2014-2019, Ilya Kotov <forkotov02@ya.ru>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -35,6 +35,7 @@
 #include <QTimer>
 #include <QIcon>
 #include <QRegExp>
+#include <QMimeDatabase>
 #ifdef QT_WIDGETS_LIB
 #include <QStyle>
 #include <QStyleFactory>
@@ -170,6 +171,17 @@ QVariant Qt5CTPlatformTheme::themeHint(QPlatformTheme::ThemeHint hint) const
         return QPlatformTheme::themeHint(hint);
     }
 }
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+QIcon Qt5CTPlatformTheme::fileIcon(const QFileInfo &fileInfo, QPlatformTheme::IconOptions iconOptions) const
+{
+    if((iconOptions & DontUseCustomDirectoryIcons) && fileInfo.isDir())
+        return QIcon::fromTheme(QLatin1String("inode-directory"));
+
+    QMimeDatabase db;
+    QMimeType type = db.mimeTypeForFile(fileInfo);
+    return QIcon::fromTheme(type.iconName());
+}
+#endif
 
 void Qt5CTPlatformTheme::applySettings()
 {
@@ -227,6 +239,9 @@ void Qt5CTPlatformTheme::applySettings()
         QGuiApplication::setPalette(*m_customPalette); //apply palette
 
 #ifdef QT_WIDGETS_LIB
+    if(m_customPalette && m_usePalette && !m_update)
+        qApp->setPalette(*m_customPalette);
+
     if(hasWidgets())
     {
         foreach (QWidget *w, qApp->allWidgets())
@@ -274,9 +289,10 @@ void Qt5CTPlatformTheme::readSettings()
 
     settings.beginGroup("Appearance");
     m_style = settings.value("style", "Fusion").toString();
-    if(settings.value("custom_palette", false).toBool())
+    QString schemePath = settings.value("color_scheme_path").toString();
+    if(!schemePath.isEmpty() && settings.value("custom_palette", false).toBool())
     {
-        QString schemePath = settings.value("color_scheme_path").toString();
+        schemePath = Qt5CT::resolvePath(schemePath); //replace environment variables
         m_customPalette = new QPalette(loadColorScheme(schemePath));
     }
     m_iconTheme = settings.value("icon_theme").toString();
@@ -284,8 +300,14 @@ void Qt5CTPlatformTheme::readSettings()
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 9, 0))
     if(!m_update)
     {
+        //do not mix gtk2 style and gtk3 dialogs
         QStringList keys = QPlatformThemeFactory::keys();
         QString name = settings.value("standard_dialogs", "default").toString();
+        if((m_style == QLatin1String("gtk2") || m_style == QLatin1String("qt5gtk2")) &&
+                (name == QLatin1String("gtk3") || name == QLatin1String("qt5gtk3")))
+        {
+            name = QLatin1String("gtk2");
+        }
         if(keys.contains(name))
             m_theme.reset(QPlatformThemeFactory::create(name));
         else if(name == QLatin1String("gtk2") && keys.contains("qt5gtk2"))
@@ -391,6 +413,26 @@ QPalette Qt5CTPlatformTheme::loadColorScheme(const QString &filePath)
             customPalette.setColor(QPalette::Disabled, role, QColor(disabledColors.at(i)));
         }
     }
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 12, 0))
+    else if(activeColors.count() == QPalette::NColorRoles - 1 &&
+            inactiveColors.count() == QPalette::NColorRoles - 1 &&
+            disabledColors.count() == QPalette::NColorRoles - 1)
+    {
+        //old format compatibility
+        for (int i = 0; i < QPalette::NColorRoles - 1; i++)
+        {
+            QPalette::ColorRole role = QPalette::ColorRole(i);
+            customPalette.setColor(QPalette::Active, role, QColor(activeColors.at(i)));
+            customPalette.setColor(QPalette::Inactive, role, QColor(inactiveColors.at(i)));
+            customPalette.setColor(QPalette::Disabled, role, QColor(disabledColors.at(i)));
+        }
+        QColor textColor = customPalette.text().color();
+        textColor.setAlpha(128);
+        customPalette.setColor(QPalette::Active, QPalette::PlaceholderText, textColor);
+        customPalette.setColor(QPalette::Inactive, QPalette::PlaceholderText, textColor);
+        customPalette.setColor(QPalette::Disabled, QPalette::PlaceholderText, textColor);
+    }
+#endif
     else
     {
         customPalette = *QPlatformTheme::palette(SystemPalette); //load fallback palette
