@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2018, Ilya Kotov <forkotov02@ya.ru>
+ * Copyright (c) 2014-2019, Ilya Kotov <forkotov02@ya.ru>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -92,6 +92,9 @@ void PaletteEditDialog::setPalette(const QPalette &palette)
            << tr("Normal text") << tr("Bright text") << tr("Button text") << tr("Normal background") << tr("Window") << tr("Shadow")
            << tr("Highlight") << tr("Highlighted text")  << tr("Link")  << tr("Visited link")
            << tr("Alternate background") << tr("Default") << tr("Tooltip background")  << tr("Tooltip text");
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 12, 0))
+    labels << tr("Placeholder text");
+#endif
     m_ui->tableWidget->setVerticalHeaderLabels(labels);
 }
 
@@ -103,7 +106,7 @@ void PaletteEditDialog::hideEvent(QHideEvent *)
 
 void PaletteEditDialog::on_tableWidget_itemClicked(QTableWidgetItem *item)
 {
-    QColor color = QColorDialog::getColor(item->backgroundColor(), this, tr("Select Color"));
+    QColor color = QColorDialog::getColor(item->backgroundColor(), this, tr("Select Color"), QColorDialog::ShowAlphaChannel);
     if(color.isValid())
     {
         item->setBackgroundColor(color);
