@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2018, Ilya Kotov <forkotov02@ya.ru>
+ * Copyright (c) 2014-2019, Ilya Kotov <forkotov02@ya.ru>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -30,6 +30,7 @@
 #include <QLocale>
 #include <QLatin1String>
 #include <QStandardPaths>
+#include <QRegularExpression>
 #include "qt5ct.h"
 
 #ifndef QT5CT_DATADIR
@@ -114,3 +115,24 @@ QString Qt5CT::systemLanguageID()
 #endif
     return  QLocale::system().name();
 }
+
+QString Qt5CT::resolvePath(const QString &path)
+{
+    QString tmp = path;
+    tmp.replace("~", QStandardPaths::writableLocation(QStandardPaths::HomeLocation));
+    if(!tmp.contains("$"))
+        return tmp;
+
+    //find environment variables
+    QRegularExpression regexp("\\$([A-Z_]+)\\/");
+    QRegularExpressionMatchIterator it = regexp.globalMatch(tmp);
+
+    while (it.hasNext())
+    {
+        QRegularExpressionMatch match = it.next();
+        QString captured = match.captured(1);
+        tmp.replace(QLatin1String("$") + captured, qgetenv(captured.toLatin1().constData()) );
+    }
+
+    return tmp;
+}
