@@ -14,136 +14,136 @@
         <translation>Anteprima</translation>
     </message>
     <message>
-        <location filename="../appearancepage.ui" line="66"/>
+        <location filename="../appearancepage.ui" line="69"/>
         <source>Active palette</source>
         <translation>Colori attivi</translation>
     </message>
     <message>
-        <location filename="../appearancepage.ui" line="71"/>
+        <location filename="../appearancepage.ui" line="74"/>
         <source>Inactive palette</source>
         <translation>Colori inattivi</translation>
     </message>
     <message>
-        <location filename="../appearancepage.ui" line="76"/>
+        <location filename="../appearancepage.ui" line="79"/>
         <source>Disabled palette</source>
         <translation>Colori disabilitati</translation>
     </message>
     <message>
-        <location filename="../appearancepage.ui" line="107"/>
+        <location filename="../appearancepage.ui" line="113"/>
         <source>Palette</source>
         <translation>Colori</translation>
     </message>
     <message>
-        <location filename="../appearancepage.ui" line="118"/>
-        <location filename="../appearancepage.cpp" line="86"/>
+        <location filename="../appearancepage.ui" line="124"/>
+        <location filename="../appearancepage.cpp" line="88"/>
         <source>Default</source>
         <translation>Predefiniti</translation>
     </message>
     <message>
-        <location filename="../appearancepage.ui" line="128"/>
+        <location filename="../appearancepage.ui" line="134"/>
         <source>Custom</source>
         <translation>Personalizzati</translation>
     </message>
     <message>
-        <location filename="../appearancepage.ui" line="155"/>
+        <location filename="../appearancepage.ui" line="161"/>
         <source>Color scheme:</source>
         <translation>Schema colori:</translation>
     </message>
     <message>
-        <location filename="../appearancepage.ui" line="178"/>
+        <location filename="../appearancepage.ui" line="187"/>
         <source>...</source>
         <translation>...</translation>
     </message>
     <message>
-        <location filename="../appearancepage.ui" line="209"/>
+        <location filename="../appearancepage.ui" line="218"/>
         <source>Standard dialogs:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="69"/>
+        <location filename="../appearancepage.cpp" line="71"/>
         <source>Create</source>
         <translation>Crea</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="70"/>
+        <location filename="../appearancepage.cpp" line="72"/>
         <source>Edit</source>
         <translation>Modifica</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="71"/>
+        <location filename="../appearancepage.cpp" line="73"/>
         <source>Create a Copy</source>
         <translation>Crea una copia</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="72"/>
+        <location filename="../appearancepage.cpp" line="74"/>
         <source>Rename</source>
         <translation>Rinomina</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="74"/>
+        <location filename="../appearancepage.cpp" line="76"/>
         <source>Remove</source>
         <translation>Rimuovi</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="141"/>
-        <location filename="../appearancepage.cpp" line="215"/>
-        <location filename="../appearancepage.cpp" line="254"/>
+        <location filename="../appearancepage.cpp" line="143"/>
+        <location filename="../appearancepage.cpp" line="217"/>
+        <location filename="../appearancepage.cpp" line="256"/>
         <source>Enter Color Scheme Name</source>
         <translation>Inserisci nome dello schema colori</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="141"/>
-        <location filename="../appearancepage.cpp" line="215"/>
-        <location filename="../appearancepage.cpp" line="254"/>
+        <location filename="../appearancepage.cpp" line="143"/>
+        <location filename="../appearancepage.cpp" line="217"/>
+        <location filename="../appearancepage.cpp" line="256"/>
         <source>File name:</source>
         <translation>Nome file:</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="150"/>
-        <location filename="../appearancepage.cpp" line="226"/>
-        <location filename="../appearancepage.cpp" line="234"/>
-        <location filename="../appearancepage.cpp" line="264"/>
+        <location filename="../appearancepage.cpp" line="152"/>
+        <location filename="../appearancepage.cpp" line="228"/>
+        <location filename="../appearancepage.cpp" line="236"/>
+        <location filename="../appearancepage.cpp" line="266"/>
         <source>Error</source>
         <translation>Errore</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="150"/>
-        <location filename="../appearancepage.cpp" line="226"/>
-        <location filename="../appearancepage.cpp" line="264"/>
+        <location filename="../appearancepage.cpp" line="152"/>
+        <location filename="../appearancepage.cpp" line="228"/>
+        <location filename="../appearancepage.cpp" line="266"/>
         <source>The color scheme &quot;%1&quot; already exists</source>
         <translation>Lo schema colori &quot;%1&quot; è già esistente</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="168"/>
-        <location filename="../appearancepage.cpp" line="191"/>
-        <location filename="../appearancepage.cpp" line="249"/>
+        <location filename="../appearancepage.cpp" line="170"/>
+        <location filename="../appearancepage.cpp" line="193"/>
+        <location filename="../appearancepage.cpp" line="251"/>
         <source>Warning</source>
         <translation>Attenzione</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="168"/>
-        <location filename="../appearancepage.cpp" line="191"/>
-        <location filename="../appearancepage.cpp" line="249"/>
+        <location filename="../appearancepage.cpp" line="170"/>
+        <location filename="../appearancepage.cpp" line="193"/>
+        <location filename="../appearancepage.cpp" line="251"/>
         <source>The color scheme &quot;%1&quot; is read only</source>
         <translation>Lo schema colori &quot;%1&quot; è in sola lettura</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="196"/>
+        <location filename="../appearancepage.cpp" line="198"/>
         <source>Confirm Remove</source>
         <translation>Conferma rimozione</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="197"/>
+        <location filename="../appearancepage.cpp" line="199"/>
         <source>Are you sure you want to remove color scheme &quot;%1&quot;?</source>
         <translation>Sei sicuro di voler rimuovere lo schema colori &quot;%1&quot;?</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="217"/>
+        <location filename="../appearancepage.cpp" line="219"/>
         <source>%1 (copy)</source>
         <translation>%1 (copia)</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="234"/>
+        <location filename="../appearancepage.cpp" line="236"/>
         <source>Unable to copy file</source>
         <translation type="unfinished"></translation>
     </message>
@@ -259,12 +259,12 @@
         <translation>Elimina fonts.conf</translation>
     </message>
     <message>
-        <location filename="../fontspage.cpp" line="115"/>
+        <location filename="../fontspage.cpp" line="110"/>
         <source>Remove Font Configuration</source>
         <translation>Elimina la configurazione dei font</translation>
     </message>
     <message>
-        <location filename="../fontspage.cpp" line="116"/>
+        <location filename="../fontspage.cpp" line="111"/>
         <source>Are you sure you want to delete &lt;i&gt;%1&lt;/i&gt;?</source>
         <translation>Sei sicuro di voler eliminare &lt;i&gt;%1&lt;/i&gt;?</translation>
     </message>
@@ -403,35 +403,75 @@
         <translation>Strumento di configurazione Qt5</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="45"/>
+        <location filename="../mainwindow.ui" line="45"/>
+        <source>The application is not configured correctly.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="52"/>
+        <source>Information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="59"/>
+        <source>Hide</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="49"/>
         <source>Appearance</source>
         <translation>Aspetto</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="46"/>
+        <location filename="../mainwindow.cpp" line="50"/>
         <source>Fonts</source>
         <translation>Caratteri</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="47"/>
+        <location filename="../mainwindow.cpp" line="51"/>
         <source>Icon Theme</source>
         <translation>Tema icone</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="48"/>
+        <location filename="../mainwindow.cpp" line="52"/>
         <source>Interface</source>
         <translation>Interfaccia</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="50"/>
+        <location filename="../mainwindow.cpp" line="54"/>
         <source>Style Sheets</source>
         <translation>Fogli di stile</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="58"/>
+        <location filename="../mainwindow.cpp" line="62"/>
         <source>Version: %1</source>
         <translation>Versione: %1</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="107"/>
+        <source>Warning</source>
+        <translation type="unfinished">Attenzione</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="116"/>
+        <source>Please remove the &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; environment variable (current value: &lt;b&gt;%1&lt;/b&gt;).</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="122"/>
+        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set (required value: &lt;b&gt;qt5ct&lt;/b&gt;).</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="126"/>
+        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set correctly (current value: &lt;b&gt;%1&lt;/b&gt;, required value: &lt;b&gt;qt5ct&lt;/b&gt;).</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="133"/>
+        <source>Unable to find &lt;b&gt;libqt5ct-style.so&lt;/b&gt;</source>
+        <translation type="unfinished">Impossibile trovare &lt;b&gt;libqt5ct-style.so&lt;/b&gt;</translation>
+    </message>
 </context>
 <context>
     <name>PaletteEditDialog</name>
@@ -571,7 +611,12 @@
         <translation>Sfondo alternativo</translation>
     </message>
     <message>
-        <location filename="../paletteeditdialog.cpp" line="106"/>
+        <location filename="../paletteeditdialog.cpp" line="96"/>
+        <source>Placeholder text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../paletteeditdialog.cpp" line="109"/>
         <source>Select Color</source>
         <translation>Seleziona colore</translation>
     </message>
@@ -584,27 +629,27 @@
         <translation>Finestra di anteprima</translation>
     </message>
     <message>
-        <location filename="../previewform.ui" line="24"/>
+        <location filename="../previewform.ui" line="27"/>
         <source>Tab 1</source>
         <translation>Linguetta 1</translation>
     </message>
     <message>
-        <location filename="../previewform.ui" line="30"/>
+        <location filename="../previewform.ui" line="36"/>
         <source>PushButton</source>
         <translation>Pulsante</translation>
     </message>
     <message>
-        <location filename="../previewform.ui" line="51"/>
+        <location filename="../previewform.ui" line="65"/>
         <source>Tab 2</source>
         <translation>Linguetta 2</translation>
     </message>
     <message>
-        <location filename="../previewform.ui" line="57"/>
+        <location filename="../previewform.ui" line="74"/>
         <source>RadioButton</source>
         <translation>Pulsante a scelta singola</translation>
     </message>
     <message>
-        <location filename="../previewform.ui" line="64"/>
+        <location filename="../previewform.ui" line="84"/>
         <source>CheckBox</source>
         <translation>Casella di spunta</translation>
     </message>
@@ -726,27 +771,4 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>main</name>
-    <message>
-        <location filename="../main.cpp" line="62"/>
-        <source>Please remove the &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; environment variable</source>
-        <translation>Rimuovi la variabile d&apos;ambiente &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt;</translation>
-    </message>
-    <message>
-        <location filename="../main.cpp" line="67"/>
-        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set correctly</source>
-        <translation>La variabile d&apos;ambiente &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; non è impostata correttamente</translation>
-    </message>
-    <message>
-        <location filename="../main.cpp" line="73"/>
-        <source>Unable to find &lt;b&gt;libqt5ct-style.so&lt;/b&gt;</source>
-        <translation>Impossibile trovare &lt;b&gt;libqt5ct-style.so&lt;/b&gt;</translation>
-    </message>
-    <message>
-        <location filename="../main.cpp" line="78"/>
-        <source>Error</source>
-        <translation>Errore</translation>
-    </message>
-</context>
 </TS>
